@@ -1,6 +1,6 @@
 package Task::BeLike::FIBO;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 1;
 
@@ -20,9 +20,17 @@ Task::BeLike::FIBO -- Leonardo Pisano a.k.a. Fibonacci
 
 =head1 SYNOPSIS
 
+Read how I create Perl packages
+
     cpan Task::BeLike::FIBO
     perldoc Task::BeLike::FIBO
 
+Create a CPAN package
+
+    mkdir My-Package-pm
+    cd My-Package-pm
+    wget -q http://g14n.info/Task-BeLike-FIBO-pm/scaffolding -O - | bash
+
 =head1 DESCRIPTION
 
 Hi! I am L<FIBO|https://metacpan.org/author/FIBO>, an italian mathematician. I graduated in 2005 at L<Università degli Studi di Genova|http://www.dima.unige.it/> and since then I work doing Business Intelligence and Web Analytics. My boss said: you need Perl. So I started using this language. I like many programming languages, but, Perl really help me to pay my rent.
@@ -134,8 +142,7 @@ Yes, it is always a good idea to add a README. If the package is not open source
 
 Get it with this command
 
-    $ wget http://g14n.info/Task-BeLike-FIBO-pm/.travis.yml
-
+    $ wget http://g14n.info/Task-BeLike-FIBO-pm/travis.yml -O .travis.yml
 
 =item *
 
@@ -143,7 +150,7 @@ Get it with this command
 
 Get it with this command
 
-    $ wget http://g14n.info/Task-BeLike-FIBO-pm/_gitignore
+    $ wget http://g14n.info/Task-BeLike-FIBO-pm/gitignore -O .gitignore
 
 =item *
 
@@ -210,7 +217,7 @@ Changes
 
 It is considered a good habit to keep track of at least major changes to inform users what they should expect when upgrading version.
 
-    2014-12-02 v0.01
+    0.01 2014-12-02
     + First release
 
 =back
@@ -266,6 +273,10 @@ Use L<Semantic Versioning|http://semver.org/>.
 
 Check that C<Changes> file is updated with modifications.
 
+Update code coverage report if it is in place, see L<CODE COVERAGE|#CODE-COVERAGE> section.
+
+Update GitHub Pages if used, see L<GITHUB PAGES|#GITHUB-PAGES> section.
+
 Create a new release
 
     $ perl Makefile.PL
@@ -298,6 +309,12 @@ Upload to L<PAUSE|http://pause.perl.org/>
 
 =item *
 
+L<App::Ack>
+
+Yes, I was hooked by L<ack>. See also L<ack.vim|https://github.com/mileszs/ack.vim> and L<ack-tutorial|https://github.com/djanowski/ack-tutorial>.
+
+=item *
+
 L<CPAN>
 
 See how to setup L<A CPAN client that works like a charm|http://g14n.info/2014/03/a-cpan-client-that-works-like-charm>.
@@ -324,9 +341,9 @@ It is a core module since Perl C<v5.8.9>.
 
 L<Perl::Tidy>
 
-Use L<Perl::Tidy> defaults; the only customization it is worth to set IMHO is
+Get a C<.perltidyrc> file
 
-    $ echo l=80 > ~/.perltidyrc # increase maximum line length
+    $ wget http://g14n.info/Task-BeLike-FIBO-pm/perltidyrc -O .perltidyrc
 
 However, do not indent every source file automatically. Indent by hand and use your creativity.
 
@@ -334,11 +351,17 @@ See Perl section in L<My Vim preferences|http://g14n.info/2013/07/my-vim-configu
 
 =item *
 
+L<PPI::HTML>
+
+Used to generate code coverage reports with highlighted syntax.
+
+=item *
+
 L<Test::Compile>
 
 Create a C<t/_compile.t> file
 
-    $ mkdir -p t; wget http://g14n.info/Task-BeLike-FIBO-pm/t/_compile.t -O t/_compile.t
+    $ mkdir -p t; wget http://g14n.info/Task-BeLike-FIBO-pm/t/compile.t -O t/_compile.t
 
 =item *
 
@@ -350,11 +373,19 @@ L<Test::Pod>
 
 Create a C<t/_pod.t> file
 
-    $ mkdir -p t; wget http://g14n.info/Task-BeLike-FIBO-pm/t/_pod.t -O t/_pod.t
+    $ mkdir -p t; wget http://g14n.info/Task-BeLike-FIBO-pm/t/pod.t -O t/_pod.t
 
 =item *
 
-L<Term::ReadLine::Perl> and L<Term::ReadKey> to L<enable history|http://g14n.info/2014/03/a-cpan-client-that-works-like-charm/#enable-history> of L<cpan> client.
+L<Term::ReadLine::Perl> and L<Term::ReadKey> to L<enable cpan history|http://g14n.info/2014/03/a-cpan-client-that-works-like-charm/#enable-history> of L<cpan> client.
+
+=item *
+
+L<V>
+
+I find it very comfortable to know a package C<Foo> version with
+
+    $ perl -MV=Foo
 
 =back
 
@@ -385,24 +416,20 @@ Create a folder that will contain code coverage metrics report
 
     $ mkdir -p gh-pages/code
 
-Install L<Devel::Cover>
-
-    $ cpan Devel::Cover
-
 Run tests with a L<Devel::Cover> harness, it will take more time than running bare tests
 
     $ export HARNESS_PERL_SWITCHES=-MDevel::Cover
     $ prove -l
 
-Generate html report
-
-    $ cover -outputdir gh-pages/code
-
 Remove harness flag, otherwise all tests in your current session will run and compute coverage.
 
     $ unset HARNESS_PERL_SWITCHES
 
-See also L<GitHub Pages|#GITHUB-PAGES> section for instructions about how to commit.
+Generate html report
+
+    $ cover -outputdir gh-pages/code -report html_basic
+
+See also L<GitHub Pages|#GITHUB-PAGES> section for instructions about how to commit generated html report.
 
 Don't forget to add a link to the html report somewhere in your documentation, something like
 
